==> docfbe_2_3_35_62.zip: docfbe_2_2_35_62/source/TCFbERowCachedTable.cpp <==
/*
    TCFbERowCachedTable.cpp    November 29, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbERowCachedTable.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^iLbV쐬
__fastcall TCFbERowCachedTable::TCFbERowCachedTable(void)
    : TCFbECachedTable()
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbERowCachedTable::~TCFbERowCachedTable()
{
}

//---------------------------------------------------------------------------
// ȉCprotected method
//---------------------------------------------------------------------------
// eLbṼZXVꂽ
void __fastcall TCFbERowCachedTable::ParentCellIsUpdated(int RowIndex, int ColumnIndex)
{
    TCFbECachedTable::ParentCellIsUpdated(RowIndex, 0);
}

//---------------------------------------------------------------------------
// eLbV̍sǉꂽ
int __fastcall  TCFbERowCachedTable::ParentAddRow(AnsiString RowLabel)
{
    if (this->GetNumberOfColumns() == 0) {
        this->AddColumn("column_0");
    }
    return this->AddRow(RowLabel);
}

//---------------------------------------------------------------------------
// eLbV̗񂪒ǉꂽ
int __fastcall  TCFbERowCachedTable::ParentAddColumn(AnsiString ColumnLabel)
{
    return -1;  // Ȃ
}

//---------------------------------------------------------------------------
// eLbV̍s폜ꂽ
void __fastcall TCFbERowCachedTable::ParentDeleteRowByIndex(int TargetRowIndex)
{
    this->DeleteRowByIndex(TargetRowIndex);
}

//---------------------------------------------------------------------------
// eLbV̗񂪍폜ꂽ
void __fastcall TCFbERowCachedTable::ParentDeleteColumnByIndex(int TargetColumnIndex)
{
    return; // Ȃ
}

//---------------------------------------------------------------------------
// g̃N[쐬
TCFbECachedTable* __fastcall TCFbERowCachedTable::CreateClone(void)
{
    TCFbERowCachedTable* Clone = new TCFbERowCachedTable();
    Clone->Assign(this);
    return Clone;
}

//---------------------------------------------------------------------------
// g̍sƗ񂪓ւN[쐬
TCFbECachedTable* __fastcall TCFbERowCachedTable::CreateRotatedClone(void)
{
    TCFbEColumnCachedTable* Clone = new TCFbEColumnCachedTable();
    Clone->RotatedAssign(this);
    return Clone;
}

//---------------------------------------------------------------------------

==> docfbe_2_3_37_64.zip: docfbe_2_3_37_64/source/TCFbERowCachedTable.cpp <==
/*
    TCFbERowCachedTable.cpp    November 29, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbERowCachedTable.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^iLbV쐬
__fastcall TCFbERowCachedTable::TCFbERowCachedTable(void)
    : TCFbECachedTable()
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbERowCachedTable::~TCFbERowCachedTable()
{
}

//---------------------------------------------------------------------------
// ȉCprotected method
//---------------------------------------------------------------------------
// eLbṼZXVꂽ
void __fastcall TCFbERowCachedTable::ParentCellIsUpdated(int RowIndex, int ColumnIndex)
{
    TCFbECachedTable::ParentCellIsUpdated(RowIndex, 0);
}

//---------------------------------------------------------------------------
// eLbV̍sǉꂽ
int __fastcall  TCFbERowCachedTable::ParentAddRow(const char* RowLabel)
{
    if (this->GetNumberOfColumns() == 0) {
        this->AddColumn("column_0");
    }
    return this->AddRow(RowLabel);
}

//---------------------------------------------------------------------------
// eLbV̗񂪒ǉꂽ
int __fastcall  TCFbERowCachedTable::ParentAddColumn(const char* ColumnLabel)
{
    return -1;  // Ȃ
}

//---------------------------------------------------------------------------
// eLbV̍s폜ꂽ
void __fastcall TCFbERowCachedTable::ParentDeleteRowByIndex(int TargetRowIndex)
{
    this->DeleteRowByIndex(TargetRowIndex);
}

//---------------------------------------------------------------------------
// eLbV̗񂪍폜ꂽ
void __fastcall TCFbERowCachedTable::ParentDeleteColumnByIndex(int TargetColumnIndex)
{
    return; // Ȃ
}

//---------------------------------------------------------------------------
// g̃N[쐬
TCFbECachedTable* __fastcall TCFbERowCachedTable::CreateClone(void)
{
    TCFbERowCachedTable* Clone = new TCFbERowCachedTable();
    Clone->Assign(this);
    return Clone;
}

//---------------------------------------------------------------------------
// g̍sƗ񂪓ւN[쐬
TCFbECachedTable* __fastcall TCFbERowCachedTable::CreateRotatedClone(void)
{
    TCFbEColumnCachedTable* Clone = new TCFbEColumnCachedTable();
    Clone->RotatedAssign(this);
    return Clone;
}

//---------------------------------------------------------------------------
